﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.IO;
using System.Runtime.InteropServices;

namespace CsKaomoji
{
    public partial class FormMain : Form
    {
        [DllImport("user32.dll")]
        private static extern UInt32 GetWindowLong(IntPtr hWnd, GWL index);
        [DllImport("user32.dll")]
        private static extern UInt32 SetWindowLong(IntPtr hWnd, GWL index, UInt32 unValue);

        const UInt32 WS_EX_NOACTIVATE = 0x8000000;
        private enum GWL : int
        {
            WINDPROC = -4,
            HINSTANCE = -6,
            HWNDPARENT = -8,
            ID = -12,
            STYLE = -16,
            EXSTYLE = -20,
            USERDATA = -21,
        }

        private void SetNoActive(IntPtr hWnd)
        {
            UInt32 unStyle = GetWindowLong(hWnd, GWL.EXSTYLE);
            unStyle = (unStyle | WS_EX_NOACTIVATE);
            SetWindowLong(hWnd, GWL.EXSTYLE, unStyle);
        }

        public FormMain()
        {
            InitializeComponent();

            Initialize();
        }

        private const string LOAD_FILENAME = "kaomoji.txt"; 
        private const int MARGIN_WIDTH = 4;
        private const int MARGIN_HEIGHT = 4;
        private const int BUTTON_HEIGHT = 20;
        private const int FONT_SIZE = 16;

        private Button CreateButtonSub(string buttonText)
        {
            Button btn = new Button();
            btn.Width = flowLayoutPanelMain.Width - MARGIN_WIDTH - 24;
            btn.Height = FONT_SIZE + 12;

            btn.Margin = new Padding(2, 2, 2, 2);

            btn.FlatStyle = FlatStyle.Standard;
            btn.FlatAppearance.BorderSize = 1;

            string fontname;
            // fontname = "Sans Serif Collection";
            fontname = "Segoe UI";

            FontFamily fontFamily = new FontFamily(fontname);
            Font font = new Font(
               fontFamily,
               FONT_SIZE,
               FontStyle.Regular,
               GraphicsUnit.Pixel);

            btn.Font = font;
            btn.Text = buttonText;
            btn.Click += new EventHandler(button_Click);

            return btn;
        }

        private void button_Click(object sender, EventArgs e)
        {
            Button button = (Button)sender;
            Clipboard.SetText(button.Text);
            SendKeys.Send("^v");
        }

        private void Initialize()
        {
            SetNoActive(this.Handle);

            string fullPath = Path.Combine(Path.GetDirectoryName(Application.ExecutablePath), LOAD_FILENAME);
            IEnumerable<string> lines = File.ReadLines(fullPath);
            foreach (string line in lines)
            {
                flowLayoutPanelMain.Controls.Add(CreateButtonSub(line));
            }
        }

        private void FormMain_Load(object sender, EventArgs e)
        {

        }
    }
}
